CommBus.Storage.Migrations (CommBus v0.1.0)

Copy Markdown View Source

Helper functions for adding CommBus tables to your Ecto migrations.

Usage

defmodule MyApp.Repo.Migrations.AddCommBusTables do
  use Ecto.Migration
  import CommBus.Storage.Migrations

  def change do
    create_comm_bus_tables()
  end
end

Summary

Functions

Creates the comm_bus_entries and comm_bus_conversations tables with all required columns, indexes, and timestamps. Call from an Ecto migration's change/0 callback.

Drops the comm_bus_conversations and comm_bus_entries tables. Call from an Ecto migration's change/0 callback to reverse create_comm_bus_tables/0.

Functions

create_comm_bus_tables()

(macro)

Creates the comm_bus_entries and comm_bus_conversations tables with all required columns, indexes, and timestamps. Call from an Ecto migration's change/0 callback.

drop_comm_bus_tables()

(macro)

Drops the comm_bus_conversations and comm_bus_entries tables. Call from an Ecto migration's change/0 callback to reverse create_comm_bus_tables/0.