CommBus.Template.RenderResult (CommBus v0.1.0)

Copy Markdown View Source

Holds the output of a successful template render, including the rendered content string, lists of variables that were used, defaulted, or provided, any partials that were loaded, and the wall-clock render time.

Summary

Types

t()

@type t() :: %CommBus.Template.RenderResult{
  content: String.t(),
  partials_loaded: [String.t()],
  render_time_ms: non_neg_integer(),
  variables_defaulted: [String.t()],
  variables_provided: [String.t()],
  variables_used: [String.t()]
}