Helper for retrieving the configured semantic adapter.
Summary
Functions
Returns the configured semantic similarity adapter module, checking options
first, then application config, and falling back to CommBus.Semantic.SimpleAdapter.
Functions
Returns the configured semantic similarity adapter module, checking options
first, then application config, and falling back to CommBus.Semantic.SimpleAdapter.
Parameters
opts— Keyword options;:semantic_adapteroverrides the configured adapter.
Returns
The adapter module (an atom implementing CommBus.Semantic.Adapter).